/* menu for the system*/

div.menu_system
{
/*	width:100%;
	height:63px;*/
}

div.menu_system ul
{
	list-style-type:none;
	margin:0;
	padding:0;
	position: absolute;
	top: 0px;
	right: 0px;
}

div.menu_system li
{
	float:left;
}

div.menu_system a
{
	display:block;
	width:86px;
}

div.menu_system a:link,div.menu_system a:visited
{
	font-family:Arial;
	font-size:10px;
	color:#FFFFFF;
	background-color:#0000A0;
	text-align:center;
	padding:4px;
	text-decoration:none;
}

div.menu_system a:hover,div.menu_system a:active
{
	background-color:#3232D2;
}


/* error message */
div.error
{
	padding:2px 4px;
	margin:0px;
	border:solid 1px #FBD3C6;
	background:#FDE4E1;
	color:#CB4721;
	font-family:Arial, Helvetica, sans-serif;
	font-size:14px;
	font-weight:bold;
	text-align:center;
}

div.success
{
	padding:2px 4px;
	margin:0px;
	border:solid 1px #C0F0B9;
	background:#D5FFC6;
	color:#48A41C; 
	font-family:Arial, Helvetica, sans-serif; font-size:14px; 
	font-weight:bold;
	text-align:center;
}
